<?php

namespace App\Http\Controllers\Api;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Auth;
use Illuminate\Http\Request;
use App\Models\ChurchPrayerPoint;
use App\Models\PrayerCategory;

class ChurchPointController extends Controller
{
    public function AddChurchPoint(Request $request)
    {
        try {
            $user = Auth::user();
    
            if (!$user) {
                return response()->json([
                    'status' => 404,
                    'message' => 'User not found',
                ], 404);
            }
    
            $user_id = $user->id;
            $church_id = $user->church_id;
    
            // Validating fields
            $validator = Validator::make($request->all(), [
                'prayer_point' => 'required|string|max:250',
            ]);
    
            if ($validator->fails()) {
                return response()->json([
                    'status' => 422,
                    'validation_errors' => $validator->errors(),
                    'message' => 'Validation failed',
                ], 422);
            }
    
            // Fetching the prayer category ID
            $prayer_category_id = PrayerCategory::where('prayer_category_name', 'Pray for my Church')->pluck('id')->first();
    
            if (!$prayer_category_id) {
                return response()->json([
                    'status' => 404,
                    'message' => 'Prayer category not found',
                ], 404);
            }
    
            // Creating a new prayer point
            $Prayerpoint = new ChurchPrayerPoint();
            $Prayerpoint->user_id = $user_id;
            $Prayerpoint->church_id = $church_id;
            $Prayerpoint->prayer_category_id = $prayer_category_id;
            $Prayerpoint->prayer_point = $request->prayer_point;
            $Prayerpoint->save();
    
            return response()->json([
                'status' => 200,
                'message' => 'Prayer Point added successfully',
                'Prayerpoint' => $Prayerpoint,
            ], 200);
    
        } catch (\Exception $e) {
            return response()->json([
                'status' => 500,
                'message' => 'An error occurred while adding the prayer point',
                'error' => $e->getMessage(),
            ], 500);
        }
    }
    

    public function ShowsChurchPoint(){

        try {
            $church_prayer_points = ChurchPrayerPoint::where('status','Active')->get();
    
            return response()->json([
                'status' => 200,
                'message' => 'Prayer Points retrieved successfully',
                'church_prayer_points' =>$church_prayer_points,

            ], 200);
        } catch (\Exception $e) {
            return response()->json([
                'status' => 500,
                'message' => 'An error occurred while retrieving prayer requests',
                'error' => $e->getMessage(),
            ], 500);
        }
    }
    
    public function EditChurchpoint($id){

        try {
            $prayerpoint = ChurchPrayerPoint::find($id);
            if (!$prayerpoint) {
                return response()->json([
                    'status' => 404,
                    'message' => 'Prayer Point record not found',
                ], 404);
            }
            return response()->json([
                'status' => 200,
                'message' => 'Prayer Point Data retrieved successfully',
                'prayerpoint' => [
                    'id'=>$prayerpoint->id,
                    'prayer_point' => $prayerpoint->prayer_point,
          
                ],

            ], 200);
        } catch (\Exception $e) {
           
            return response()->json([
                'status' => 500,
                'message' => 'An error occurred while retrieving the user',
                'error' => $e->getMessage(),
            ], 500);
        }

    }

    public function UpdateChurchpoint(Request $request, $id){
        try {
 
            $churchprayerpoint = ChurchPrayerPoint::find($id);
            if (!$churchprayerpoint) {
             return response()->json([
                 'status' => 404,
                 'message' => 'Prayer Point not found',
             ], 404);
         }

         // Validate incoming data
         $validator = Validator::make($request->all(), [
            'prayer_point' => 'required|string|max:250',
         ]);
 
         if ($validator->fails()) {
             return response()->json([
                 'status' => 422,
                 'validation_errors' => $validator->errors(),
                 'message' => 'Validation failed',
             ], 422);
         }
 
         $churchprayerpoint->prayer_point = $request->input('prayer_point');
         $churchprayerpoint->save();
 
         return response()->json([
             'status' => 200,
             'message' => 'Prayer point updated successfully',
            'churchprayerpoint' => [
                 'id'=>$churchprayerpoint->id,
                 'prayer_point' => $churchprayerpoint->prayer_point,
             ],
         ], 200);
 
     } catch (\Exception $e) {
         return response()->json([
             'status' => 500,
             'message' => 'An error occurred while updating the Prayer Point',
             'error' => $e->getMessage(),
         ], 500);
     }
    }

    public function DeleteChurchpoint($id){
        try {
            $churchprayerpoint = ChurchPrayerPoint::find($id);
    
            if (!$churchprayerpoint) {
                return response()->json([
                    'status' => 404,
                    'message' => 'Church Prayer Point not found',
                ], 404);
            }
            $churchprayerpoint->delete();
    
            return response()->json([
                'status' => 200,
                'message' => 'Church Prayer point deleted successfully',
            ], 200);
        } catch (\Exception $e) {
            return response()->json([
                'status' => 500,
                'message' => 'An error occurred while deleting the user',
                'error' => $e->getMessage(),
            ], 500);
        }
    }

    public function FilteredPrayerPoint(Request $request){

        $Churchpoint = ChurchPrayerPoint::query();

        if ($request->has('view_all')) {
            return response()->json($Churchpoint->get(), 200);
        }

        if ($request->has('prayed_prayers')) {
            $Churchpoint->where('is_prayed', 1);
        }

        if ($request->has('unprayed_prayers')) {
            $Churchpoint->where('is_prayed', 0);
        }

        if ($request->has('new_prayer_points')) {
            $Churchpoint->orderBy('created_at', 'desc')->limit(5); 
        }

        return response()->json($Churchpoint->get(), 200);
    }
}
