<?php

namespace App\Http\Controllers\Api;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Facades\Auth;
use App\Http\Controllers\Controller;
use App\Models\PrayerCategory;
use Illuminate\Http\Request;
use App\Models\PrayerRequest;
use Carbon\Carbon;
 
class PrayerRequestController extends Controller
{
    public function AddPrayerRequest(Request $request){

        $user = Auth::user();
        $user_id = $user->id;
        $church_id = $user->church_id;
 
        if (!$user) {
            return response()->json([
                'status' => 404,
                'message' => 'User not found',
            ], 404);
        }
        // validatting fields
        $validator = Validator::make($request->all(), [
            'description' => 'required|string|max:250', 
            'date' => [
            'required',
            'date_format:d-m-Y', 
             ],
        ]);
    
        if ($validator->fails()) {
            return response()->json([
                'status' => 422,
                'validation_errors' => $validator->errors(),
                'message' => 'Validation failed',
            ], 422);
        }
        
        $formattedDate = Carbon::parse($request->date)->format('Y-m-d');

        $prayer_category_id = PrayerCategory::where('prayer_category_name', 'Prayer Request')->pluck('id')->first();
      
        $PrayerRequest = new PrayerRequest();
        $PrayerRequest->user_id = $user_id; 
        $PrayerRequest->church_id = $church_id;
        $PrayerRequest->prayer_category_id = $prayer_category_id;
        $PrayerRequest->date = $formattedDate;
        $PrayerRequest->description = $request->description;
        $PrayerRequest->save();

        return response()->json([
            'status' => 200,
            'message' => 'PrayerRequest Created successfully',
            'PrayerRequest' => $PrayerRequest,
        ], 200);

    }


    public function PrayerRequest(){

        try {
            $prayer_requests = PrayerRequest::all();
    
            return response()->json([
                'status' => 200,
                'message' => 'Prayer requests retrieved successfully',
                'prayer_requests' => $prayer_requests,
            ], 200);
        } catch (\Exception $e) {
            return response()->json([
                'status' => 500,
                'message' => 'An error occurred while retrieving prayer requests',
                'error' => $e->getMessage(),
            ], 500);
        }
    }
}
