<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Facades\Auth;
use Illuminate\Http\Request;
use App\Models\Testimonial;
use Carbon\Carbon;

class TestimonialController extends Controller
{
    public function AddTestimonial(Request $request){

        $user = Auth::user();
        $user_id = $user->id;
        $church_id = $user->church_id;
 
        if (!$user) {
            return response()->json([
                'status' => 404,
                'message' => 'User not found',
            ], 404);
        }
        // validatting fields
        $validator = Validator::make($request->all(), [
            'description' => 'required|string|max:250', 
            'date' => [
                'required',
                'date_format:d-m-Y', 
            ],
        ]);
    
        if ($validator->fails()) {
            return response()->json([
                'status' => 422,
                'validation_errors' => $validator->errors(),
                'message' => 'Validation failed',
            ], 422);
        }
        
        $formattedDate = Carbon::parse($request->date)->format('Y-m-d');

        $Testimonial = new Testimonial();
        $Testimonial->user_id = $user_id; 
        $Testimonial->church_id = $church_id;
        $Testimonial->date = $formattedDate;
        $Testimonial->description = $request->description;
        $Testimonial->save();

        return response()->json([
            'status' => 200,
            'message' => 'Testimonial Created successfully',
            'Testimonial' => $Testimonial,
        ], 200);
    }

    public function ShowTestimonial(){
        try {
            $testimonials = Testimonial::all();
    
            return response()->json([
                'status' => 200,
                'message' => 'Testimonials retrieved successfully',
                'testimonials' => $testimonials,
            ], 200);
        } catch (\Exception $e) {
            return response()->json([
                'status' => 500,
                'message' => 'An error occurred while retrieving testimonials',
                'error' => $e->getMessage(),
            ], 500);
        }
    }
    
}
